==> holado-0.11.1.tar.gz: holado-0.11.1/src/holado_test/common/context/step_context.py <==

#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################

from builtins import super
from holado.common.context.context import Context
import logging
from holado_python.common.tools.datetime import DateTime

logger = logging.getLogger(__name__)


class StepContext(Context):
    def __init__(self, step):
        super().__init__("Step")
        
        self.__step = step
        self.__status = None
        
        self.__start_date = DateTime.now()
        self.__end_date = None
    
    def __str__(self):
        return f"{{StepContext({id(self)}):{self.step.keyword} {self.step.name}}}"

    @property
    def step(self):
        return self.__step
    
    @property
    def status(self):
        return self.__status
    
    @status.setter
    def status(self, status):
        self.__status = status
    
    @property
    def start_datetime(self):
        return self.__start_date
    
    @property
    def end_datetime(self):
        return self.__end_date
    
    @property
    def duration(self):
        if self.__end_date is not None:
            return (self.__end_date - self.__start_date).total_seconds()
        else:
            return None
    
    def end(self):
        self.__end_date = DateTime.now()

==> holado-0.13.9.tar.gz: holado-0.13.9/src/holado_test/common/context/step_context.py <==

#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################

from builtins import super
from holado.common.context.context import Context
import logging
from holado_python.common.tools.datetime import DateTime

logger = logging.getLogger(__name__)


class StepContext(Context):
    def __init__(self, step, do_start=True):
        super().__init__("Step")
        
        self.__step = step
        self.__status = None
        
        self.__start_date = DateTime.now() if do_start else None
        self.__end_date = None
    
    def __str__(self):
        return f"{{StepContext({id(self)}):{self.step.keyword} {self.step.name}}}"

    @property
    def step(self):
        return self.__step
    
    @property
    def status(self):
        return self.__status
    
    @status.setter
    def status(self, status):
        self.__status = status
    
    @property
    def start_datetime(self):
        return self.__start_date
    
    @property
    def end_datetime(self):
        return self.__end_date
    
    @property
    def duration(self):
        if self.__start_date is not None and self.__end_date is not None:
            return (self.__end_date - self.__start_date).total_seconds()
        else:
            return None
    
    def end(self):
        self.__end_date = DateTime.now()
